.. :changelog:

History
=======

0.2.2 (2020-07-12)
------------------

- added *dynamic* property to ProgressBar

0.2.1 (2020-07-12)
------------------

- minor cosmetics

0.2.0 (2020-06-28)
------------------

- added possibility for dynamic updates in runtime
- added *update()* method to ProgressBar class
- fixed a bug with *finalize()* method

0.1.1 (2020-06-28)
------------------

- added *as_percent* attribute to ProgressBar class
- added *finalize()* method to ProgressBar class

0.1.0 (2020-06-28)
------------------

* First release on PyPi
